@@ -27,13 +27,13 @@ class BaseOptimizationAlgorithm(ABC):
     def sigmoid(self, x):
         return 1/(1+np.exp(-x))
 
-    def _evaluate_fitness(self, model, X_train, y_train, X_valid, y_valid):
+    def _evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid):
         scores = []
         for i, individual in enumerate(self.individuals):
             chosen_features = [index for index in range(
-                X_train.shape[1]) if individual[index] == 1]
-            X_train_copy = X_train.iloc[:, chosen_features]
-            X_valid_copy = X_valid.iloc[:, chosen_features]
+                x_train.shape[1]) if individual[index] == 1]
+            x_train_copy = x_train.iloc[:, chosen_features]
+            x_valid_copy = x_valid.iloc[:, chosen_features]
 
             feature_hash = '_*_'.join(
                 sorted(self.feature_list[chosen_features]))
@@ -41,10 +41,11 @@ class BaseOptimizationAlgorithm(ABC):
                 score = self.feature_score_hash[feature_hash]
             else:
                 score = self.objective_function(
-                    model, X_train_copy, y_train, X_valid_copy, y_valid)
+                    model, x_train_copy, y_train, x_valid_copy, y_valid)
+                if not(self.minimize):
+                    score = -score
                 self.feature_score_hash[feature_hash] = score
-            if not(self.minimize):
-                score = -score
+
             if score < self.best_score:
                 self.best_score = score
                 self.best_dim = individual
@@ -63,11 +64,11 @@ class BaseOptimizationAlgorithm(ABC):
                                                   'selected_features': list(self.feature_list[
                                                       np.where(self.individuals[np.array(self.fitness_scores).argmin()])[0]])}
 
-    def initialize_population(self, X):
+    def initialize_population(self, x):
         self.individuals = np.random.randint(
-            0, 2, size=(self.population_size, X.shape[1]))
+            0, 2, size=(self.population_size, x.shape[1]))
 
-    def _check_params(self, model, X_train, y_train, X_valid, y_valid):
+    def _check_params(self, model, x_train, y_train, x_valid, y_valid):
         if (self.n_iteration <= 0):
             raise ValueError(
                 f"n_init should be > 0, got {self.n_iteration} instead.")
@@ -84,23 +85,23 @@ class BaseOptimizationAlgorithm(ABC):
             raise ValueError(
                 f"requires y_train to be passed, but the target y is None.")
 
-        if X_train is None:
+        if x_train is None:
             raise ValueError(
                 f"requires X_train to be passed, but the target X_train is None.")
 
-        if (type(X_train) != pd.core.frame.DataFrame):
+        if (type(x_train) != pd.core.frame.DataFrame):
             raise TypeError(f" X_train should be of type pandas.core.frame.DataFrame,\
-                            got {type(X_train)} instead.")
+                            got {type(x_train)} instead.")
 
-        if (type(X_valid) != pd.core.frame.DataFrame):
+        if (type(x_valid) != pd.core.frame.DataFrame):
             raise TypeError(f" X_valid should be of type pandas.core.frame.DataFrame,\
-                            got {type(X_valid)} instead.")
+                            got {type(x_valid)} instead.")
 
-        if X_train.shape[1] != X_valid.shape[1]:
+        if x_train.shape[1] != x_valid.shape[1]:
             raise ValueError(f" X_train and X_valid should have same number of features,\
-                             got { X_train.shape[1]},{X_valid.shape[1]} instead.")
+                             got { x_train.shape[1]},{x_valid.shape[1]} instead.")
 
-        if X_valid is None:
+        if x_valid is None:
             raise ValueError(
                 f"requires X_valid to be passed, but the target X_train is None.")
 
@@ -109,7 +110,7 @@ class BaseOptimizationAlgorithm(ABC):
                 f"requires X_valid to be passed, but the target y_valid is None.")
 
         return_val = self.objective_function(
-            model, X_train, y_train, X_valid, y_valid)
+            model, x_train, y_train, x_valid, y_valid)
         if (not (isinstance(return_val, (int, float)))):
             raise TypeError(
                 f"objective_function should return int/float value , got {type(return_val)} instead.")
